" Vim syntax file
" Language:	Gibiane
" Version:	1.0
" Last Change:  2013 Nov 22
" Maintainer:	Gauthier Folzan <gauthier.folzan@cea.fr>
" Usage:	For instructions, do :help fortran-syntax from Vim
" Credits:      Inspired from the gibiane syntax from Laurent CHAMPANEY
" Thanks to Clément Berthinier for the operator list
"
if exists("b:current_syntax")
	    finish
    endif

syn case ignore

set tw=72
set columns=72
set tabstop=2
set shiftwidth=2
set expandtab

syn match gibianeComment	"^[*].*$"
syn match  gibianeComment		"^.\{-72}.*$"lc=72
"match OverLength /\%73v.\+/
syn region gibianeString		start=+"+ end=+"+	oneline contains=gibianeType, gibianeElement, gibianeOperator, gibianeLogical, gibianeConditional, gibianeFunction, gibianeLoop, gibianeProcedure, gibianeProcPerso 
syn region gibianeString		start=+'+ end=+'+	oneline contains=gibianeType, gibianeElement, gibianeOperator, gibianeLogical, gibianeConditional, gibianeFunction, gibianeLoop, gibianeProcedure, gibianeProcPerso 
syn keyword gibianeTodo			contained TODO
syn match  gibianeReadWrite		"\<\(read\|print\)\>"
syn region gibianeReadWriteFunc		matchgroup=gibianeReadWrite start="\(read\|write\)\s*("rs=e-1,he=e-1 skip=")'" matchgroup=NONE end=")" contains=gibianeFormatString

"*** PROCEDURES ***
syn keyword gibianeProcPerso DEBP[ROC] FINP[ROC] 

" Any integer
syn match gibianeNumber		"-\=\<\d\+\>"
" floating point number, with dot, optional exponent
syn match gibianeFloat		"\<\d\+\.\d*\([edED][-+]\=\d\+\)\=\>"
" floating point number, starting with a dot, optional exponent
syn match gibianeFloat		"\.\d\+\([edED][-+]\=\d\+\)\=\>"
" floating point number, without dot, with exponent
syn match gibianeFloat		"\<\d\+[edED][-+]\=\d\+\>"


" Element types
syn keyword gibianeElement POI1 SEG2 SEG3 SEG4 SEG6 TRI3 TRI4 TRI6 TRI7
syn keyword gibianeElement TR12 TR21 QUA4 QUA5 QUA8 QUA9 QU16 QU36 RAC2
syn keyword gibianeElement RAC3 CUB8 CU20 CU27 LIA3 LIA4 LIA6 LIA8 MULT
syn keyword gibianeElement TET4 TE10 TE15 TE56 PRI6 PR15 PR18 PR21 PYR5
syn keyword gibianeElement PY13 PY19 PY91 ATTA SUPE RAP3 LIP6 LIP8 POLY
syn keyword gibianeElement C216 P126 SURE

"*** OPERATEURS ***
syn keyword gibianeOperator ACQU[ERIR] KP   DMTD PSRS COLI NLOC FROT SUIT[E] BORN[ER]
syn keyword gibianeOperator MATR ETG  RESU[LT] CUBT PAVE[R] IMPE TRAN[SLATION] CLMI MULT
syn keyword gibianeOperator FORM[E] SPO  DIAD PROG KFPT WORK DIVU PSIP KMTP
syn keyword gibianeOperator YTMX KOPS ZLEG BLOQ[UE] MATE[RIAU] EQPR RESP CSON PARC
syn keyword gibianeOperator IFRE TRAC[ER] CHPO MPRO FOFI SORT DFER PRNS KENT
syn keyword gibianeOperator VSUR ACT3 KPRO DOMA PVEC COMB NNOR FSUR SUPE
syn keyword gibianeOperator BRUI MAX1 EVOL[UTION] RETO CVOL PENT IMPF TRES CLST
syn keyword gibianeOperator MUTU FPA  SPON DIAG PROI KHIS XFEM DMMU PSMO
syn keyword gibianeOperator KONV ZERO BMTD MATP REST CUBP PART IJET
syn keyword gibianeOperator TRAJ CHSP MREM FORC[E] SOUR DFOU PROB KFPA WEIP
syn keyword gibianeOperator ACTI KRES D DROI[TE] QOND COMM NOEL FUIT SURF[ACE] BSIG[MA]
syn keyword gibianeOperator MDIA EXCE RFCO DALL[ER] PERM[EABILITE] IMPO[SER] TRIA CMCT NBEL
syn keyword gibianeOperator FPT  SQTP DIFF[ERENCE] PROJ[ETER] KLOP XTMX ADET KSIG[MA] DSPR
syn keyword gibianeOperator QUEL[CONQUE] COMP NOEU[D] GANE SYME[TRIE] CABL MENA EXCF RIGI[DITE]
syn keyword gibianeOperator DANS PERT[UBE] INCL[USION] TRIE[R] CMOY NBNO FPU  SSCH DIME[NSION]
syn keyword gibianeOperator PROP[HASE] KMAB XTX  ADVE[CTION] KSOF DUDW QULX COMT NOMC
syn keyword gibianeOperator GENE[RATRICE] SYMT CALP MENU EXCI[TER] RIMP DBIT PHAJ INDE[X]
syn keyword gibianeOperator TSCA CNEQ NEUT FRIG SSTE DIMN PRRA KMBT XTY
syn keyword gibianeOperator AFCO KTAN DYNE RACC CONC NORM[E] GENJ SYNT CAPA[CITE]
syn keyword gibianeOperator MESM EXCO ROTA[TION] DCOV PICA INDI TYPE COAC NLIN
syn keyword gibianeOperator FRON STRU DIRI PSCA KMF  XXT AFFI LAPL ECFE
syn keyword gibianeOperator RACP COND[UCTIVITE] NOTI[CE] GMV  TABL[E] CAPI MESS[AGE] EXCP RTEN
syn keyword gibianeOperator DEBI[T] PILE[PS] INFO UNIQ[UE] ARET[E] LOGK ELST REDU CORI[OLIS]
syn keyword gibianeOperator OPTI[ON] HERI[TE] TFR CFND MODE[LE] FILT SIGM[A] DEPB POLA[IRE]
syn keyword gibianeOperator ISOV[ALEUR] VERS[ENS] AMOR[TISSEMENT] LIAI[SON] ELEM[ENT] RAYE CONT[OUR] NUAG[E] GREE[N]
syn keyword gibianeOperator TCNM CCON MISE FACE SAUV[ER] DEDU PLUS INTG VARI
syn keyword gibianeOperator BARY[CENTRE] MANU[EL] ENVE[LOPPE] RELA COUP[ER] OSCI HOTA[NGE] TITR[E] CHAU[SSETTE]
syn keyword gibianeOperator MOME[NT] FION SOLS DETO PRES[SION] KBBT VISA[VIS] AJU1 LECT
syn keyword gibianeOperator ECOU[LE] RAFT CONG[E] NSKE GRAD[IENT] TAIL CARB METH[ODE] EXTE
syn keyword gibianeOperator SAUF DECO PLAC[E] INSI VALE[UR] ASSI[STANT] LTL  ENLE[VER] REGE
syn keyword gibianeOperator COTE ORIE[NTE] HOMO[THETIE] THET[A] CHAN[GER] MODL FIMP SIMP DEPL[ACER]
syn keyword gibianeOperator PRCH JACO[BIEN] VIBR[ATION] ANTI[SYMETRIE] LIRE ELIM[INER] REAC[TION] COOR[DONNE] OBTE[NIR]
syn keyword gibianeOperator HANN TEMP[S] C CERC[LE] MOCA FDT SENS DEG3 PMIX INVE[RSE]
syn keyword gibianeOperator VENV BGMO MASQ[UE] EPTH RESI COUT[URE] OUBL[ER] HYBP TOTE[MP]
syn keyword gibianeOperator CHI2 MOTA FLAM SOMT DEVE[RSOIR] PRIM KCHT VOLU[ME] AIDE
syn keyword gibianeOperator LAPN ECHI RAFF[INER] CONF NS GNFL TAGR CARA[CTERISTIQUE] MESU[RE]
syn keyword gibianeOperator EXIS[TE] SAIS[IR] DEBM PJBA INSE UTIL ARGU LSQF ENER
syn keyword gibianeOperator REFE COSI ORDO[NNER] HIST TFRI CHAI[NE] MODI[FIER] FIMP SIGS
syn keyword gibianeOperator DEPI[MPOSE] POSI[TION] ITRC VIBC ANNU LIGN[E] ELFE RAYN CONV[ECTION]
syn keyword gibianeOperator OBJE[T] GYRO TCRR CER3 MISL FANT SEIS[ME] DEFO[RME] PMAT
syn keyword gibianeOperator INVA VECT[EUR] BASE MAPP EPSI[LON] REMP[LACER] COUR[BE] OTER HVIT
syn keyword gibianeOperator TOIM CHI1 MOT  FISS SOMM[ET] DETR PRET KCHA VMIS[ES]
syn keyword gibianeOperator AJU2 LEVM ELAS[TICITE] RAVC CONN NTAB GRAF TASS CBLO
syn keyword gibianeOperator MHYB EXTR[AIRE] SAUT DEDO[UBLE] PLAS INTE VALP AVCT LUMP
syn keyword gibianeOperator ENSE[MBLE] REGL[ER] COUL[EUR] ORTH[OGONALISER] HOOK[E] TIRE CHAR[GEMENT] MOIN[S] FINM
syn keyword gibianeOperator SMTP DESS[IN] PREC JONC[T] VIDE APPU LIST[ER] ELNO RECO
syn keyword gibianeOperator COPI[ER] ONDE HDEB TEXT[E] CFL MOCU FFOR SIAR DENS[ITE]
syn keyword gibianeOperator POIN[T] IPOL VERM BIOT MASS[E] EQEX RESO[UDRE] CRIT PARA[BOLE]
syn keyword gibianeOperator IDLI TOUR CHOI MOTS FLUX SORE[T] DFDT PRIN KDIA
syn keyword gibianeOperator VORO[NOI]
"*** LOGIQUE ***
syn keyword gibianeLogical VRAI FAUX ET   OU   NON  EGA  NEG 
"conditions
syn keyword gibianeConditional SI  SINO[N] FINS[I]

"Fonctions mathematiques
syn keyword gibianeFunction COS COSH ACOS SIN SINH ASIN TAN TANH ATG ERF
syn keyword gibianeFunction EXP FACTORIE FONC LOG MINI MAXI ENTI[ER]
syn keyword gibianeFunction FLOT[TANT] SIGN[E] ALEA ABS

"*** BOUCLES ***
syn keyword gibianeLoop REPE[TER] QUIT[TER] ITER[ER] FIN 



"*** PROCEDURES AVEC @ en prefix ecrit ***
syn keyword gibianeProcedure @ALGSTA    @OTPOUT    @DEFA2DP   @TOLE3
syn keyword gibianeProcedure @CLMI1C    @REMPCOU @HELICE    @ZACPRO7
syn keyword gibianeProcedure @CHFLEC    @P_VORO    @FIS_3 @ZACPRO1
syn keyword gibianeProcedure @COUTOR1   @STATIO    @LAMASS @LAMAT
syn keyword gibianeProcedure @ANA_LIM   @PASHIST   @DEFPL @TORO
syn keyword gibianeProcedure @CLMI2C    @REMPFAT   @HISTOGR @ZACPRO8
syn keyword gibianeProcedure @CIRCONS   @RAYO @FIS_3DS @ZACPRO2
syn keyword gibianeProcedure @COUTOR2  @STBL @LAREAD    @LARIG @ARR
syn keyword gibianeProcedure @PLOTPRI   @DESLIS    @TOTAL @CLPC
syn keyword gibianeProcedure @REMPGRO   @INCLUSI @INITIA @CLCH
syn keyword gibianeProcedure @RCCM      @FIX @ZACPRO3   @CRIPL @SYSLIN
syn keyword gibianeProcedure @LASIEP  @LAVERG @B_TPO2D   @POINTIR
syn keyword gibianeProcedure @ENCA @VECOUL    @CLPD @REPERE    @ISOSURF
syn keyword gibianeProcedure @KEFF      @CLDH @RCCMCO2 @FRENET
syn keyword gibianeProcedure @ZACPRO4   @DEDUIRE   @TEST @LAVIS @LIREENT
syn keyword gibianeProcedure @CARENE    @POLO @EXCEL1    @VIS3D
syn keyword gibianeProcedure @CORIGI @SATURAT   @LACALC @LACRIT
syn keyword gibianeProcedure @CLDHC @RCCMTRV   @GATTPAR @ZACPRO5
syn keyword gibianeProcedure @DEFA2DL   @TOLE2     @LIRERIS @LISPA16
syn keyword gibianeProcedure @CARTOON   @POMI @FIS_1 @VISOR     @COUPLAN
syn keyword gibianeProcedure @SIGREF @LAFAIL @LAGRAPH   @CLIM @RELIEF
syn keyword gibianeProcedure @GLOBAL    @ZACPRO6   @LISSE @MATETHM @MESU
syn keyword gibianeProcedure @MISTPAR   @CDG @P_BOIT2   @FIS_2
syn keyword gibianeProcedure @ZACPLUS   @COUPLE    @STAT @LAKAPPA
syn keyword gibianeProcedure @LALIST    @MOD       @M_VORO @ORTHO
syn keyword gibianeProcedure @OTCOQUE   

"*** PROCEDURES AVEC @ en prefix non ecrit ***
syn keyword gibianeProcedure ALGSTA     LIRERIS    DEFA2DP    REMPGRO
syn keyword gibianeProcedure CLIM       PLOTPRI    GLOBAL TOTAL     CDG
syn keyword gibianeProcedure MOD        FIS_2 STBL      COUPLAN    RAYO
syn keyword gibianeProcedure KEFF       ZACPRO2   ANA_LIM LISPA16 DEFPL
syn keyword gibianeProcedure REPERE    CLMI1C POINTIR HELICE     VECOUL
syn keyword gibianeProcedure CHFLEC     M_VORO FIS_3      SYSLIN COUPLE
syn keyword gibianeProcedure RCCM       LACALC ZACPRO3   ARR LISSE
syn keyword gibianeProcedure DESLIS SATURAT   CLMI2C POLO       HISTOGR
syn keyword gibianeProcedure VIS3D     CIRCONS    ORTHO FIS_3DS    TEST
syn keyword gibianeProcedure COUTOR1    RCCMCO2 LACRIT     ZACPRO4
syn keyword gibianeProcedure B_TPO2D MATETHM    ENCA SIGREF    CLPC POMI
syn keyword gibianeProcedure INCLUSI    VISOR CLCH OTCOQUE    FIX
syn keyword gibianeProcedure TOLE2     COUTOR2    RCCMTRV LAFAIL ZACPRO5
syn keyword gibianeProcedure CARENE     MESU EXCEL1     STAT      CLPD
syn keyword gibianeProcedure P_BOIT2 INITIA     ZACPLUS CLDH
syn keyword gibianeProcedure OTPOUT     FRENET     TOLE3 CRIPL RELIEF
syn keyword gibianeProcedure LAGRAPH    ZACPRO6 CARTOON    MISTPAR
syn keyword gibianeProcedure FIS_1 STATIO CORIGI     P_VORO ISOSURF
syn keyword gibianeProcedure ZACPRO1   CLDHC      PASHIST GATTPAR TORO
syn keyword gibianeProcedure DEDUIRE    REMPCOU LAKAPPA    ZACPRO7
syn keyword gibianeProcedure DEFA2DL REMPFAT LALIST ZACPRO8   LAMASS
syn keyword gibianeProcedure LAMAT     LAREAD    LARIG LASIEP LAVERG
syn keyword gibianeProcedure LAVIS     LIREENT   

"*** PROCEDURES SANS PARTICULARITES ***
syn keyword gibianeProcedure ACCDCHI1 MDRECOMB CONVT    SGE      CHDCLIM
syn keyword gibianeProcedure RDIV     EXPLORER VITEUNIL BALOURD  PFLUAGE
syn keyword gibianeProcedure DEPOU    TRAC3D   INDIBETA LICOMNOM H_B
syn keyword gibianeProcedure LCH2IMPR AJUSTE   NOESPCHI DDFOUR   SISSIB
syn keyword gibianeProcedure COLLER RESPOWSP FORNOD K_PRO CALCULER
syn keyword gibianeProcedure POT_VECT DYNAMOD3 TRANSIT2 LSOSFRAC
syn keyword gibianeProcedure LSOSSOLI HTC_WWW LCH2SORT ACCDCHI2 MONTAGNE
syn keyword gibianeProcedure COUPLER  SIF      CHITRNSP RECENTRE F_S2PI
syn keyword gibianeProcedure VNIMP BIF      PHASAGE DESCOUR  TRACHIS
syn keyword gibianeProcedure INDIOBJE LIESPECE HAUBAN LCH2ITMA ANALYSER
syn keyword gibianeProcedure NONLIN   DEADFONC SPPLANC COLLER1  RETRAIT
syn keyword gibianeProcedure FOUR2TRI KEPSILON CALMU POUT2MAS DYNAMODE
syn keyword gibianeProcedure TRANSIT3 M_DAMP_K M_DAMPIN HTCTRAN
syn keyword gibianeProcedure LCH2TEMP ACCEVITE MOYESPEC COUR3D SIGNCORR
syn keyword gibianeProcedure CHPR0    RECOMPOM FDENS VTIMP BILI_EFZ PMPB
syn keyword gibianeProcedure DESTRA   TRACHIT INDUCTIO LILIDEN  HP_PRO
syn keyword gibianeProcedure LCH2ITSO ANIME    NORMALIM DEADJACO T_IPOL
syn keyword gibianeProcedure CONDENS  ROSENT   FPAL KR_PRO CAMPBELL PPRE
syn keyword gibianeProcedure EC8ACSIS TRANSLIN MAG_NLIN MAILSTRU IDBHT
syn keyword gibianeProcedure LCH2TOT ACIER    MULC COURSPEC SIGNDERI
syn keyword gibianeProcedure CHTGAU   RECOMPOS FIABILI WEIBULL BILI_MOY
syn keyword gibianeProcedure POINTCYL DONCHI1  TRACMECA INICHI1  LILIECH
syn keyword gibianeProcedure HRAYO LCH2LOGC ANIMGKS NSCLIM   DEADKTAN
syn keyword gibianeProcedure T_PITETA CONSERVE RVSAT FREPART  KUET
syn keyword gibianeProcedure CCDONCHI PREPAENC ELECNEUT TRANSNON MAYOTO
syn keyword gibianeProcedure MDNRIS IDENTI   LESPCOMP ACTI3    MULTIDEC
syn keyword gibianeProcedure CREER_3D SIGNENVE CHTITR REPART   FILTREKE
syn keyword gibianeProcedure XBIF BIOVOL   POINTSPH DONCHI2  TRACTUFI
syn keyword gibianeProcedure INICHI2 LIMEMECA HRCAV LCH2MDEL ANLIMTRE
syn keyword gibianeProcedure PARASTAT DEADRESI TAKM_EFZ CONTSEG3 RVST2
syn keyword gibianeProcedure FREQPERI LCH2CLIM CH_THETA PROBABRS
syn keyword gibianeProcedure ENCEINTE TRTRAJEC IMAGES   LESPITYP IMPCHI1
syn keyword gibianeProcedure LESPLOGK ACTUSAT1 MULTIREC CRITLOC
syn keyword gibianeProcedure SIGNSYNT CINEMA   REPIX FINVREPA ZIGZAG BOA
syn keyword gibianeProcedure POLYNO   DREXUS TRADUIRE INICHIMI LINBIDEN
syn keyword gibianeProcedure HT_PRO LCH2NFI ANNOIMP PARMCHI2 DEADUTIL
syn keyword gibianeProcedure TAKM_MOY IMPCHI2  LESPSTOE FRONABS
syn keyword gibianeProcedure LCH2DELP CH2CLIM  PROBDENS ENERMODE
syn keyword gibianeProcedure UNILATER CHANOLII PRODT ENRICHIS UNILSSUP
syn keyword gibianeProcedure ACTUSAT2 NATAF    CTOD SILAM    CINEMB
syn keyword gibianeProcedure RESEAU   FLAMBAGE ININLIN CALACTIV POSTDDI
syn keyword gibianeProcedure DUPONT2  TRANSFER INICONT LINVCOMP HTC_CHBW
syn keyword gibianeProcedure LCH2NITE ARCGAU   PASAPAS DECONV   TENSION
syn keyword gibianeProcedure IN_MINI LIBDD    G_CALCUL LCH2EPS CHANUOBJ
syn keyword gibianeProcedure PROPAG   EPAIFUT  VALNOM CHANVCOM PSATT
syn keyword gibianeProcedure EXAC VALSPE ACTUSAT3 NEWMARK DARCYSAT SISSI
syn keyword gibianeProcedure CINIMOD  RESO_ASY FOR_CONT INT_COMP
syn keyword gibianeProcedure CALCDISP POSTDDI1 DYNAMIC  TRANSIT0 INIMUR
syn keyword gibianeProcedure LIREFLOT HTC_PER  LCH2NTY4 ASPARAM  PASRESU
syn keyword gibianeProcedure DEDANS   THERMIC  INCREME LICHXMX  G_THETA
syn keyword gibianeProcedure LCH2FION CHANVESP QUADRATU EXEC     VAPDIF
syn keyword gibianeProcedure CHANVSOS RAMBERG  EXECRXT VERTYTAB AFFICHE
syn keyword gibianeProcedure NOCOMCHI DARCYTRA SISSI2 CODENORM RESPOWNS
syn keyword gibianeProcedure FORBLOC JEU CALCP    POT_SCAL DYNAMOD2
syn keyword gibianeProcedure TRANSIT1 LIRSOSO  LITEMPER HTC_WTR
syn keyword gibianeProcedure LCH2PREP AUTOPILO PECHE    DEDUADAP
syn keyword gibianeProcedure TRAC3D_2 INCREME2 LICOCHAR G_THETA1
syn keyword gibianeProcedure LCH2IAFF CHARTHER RAY      EXIC VITETFOR
syn keyword gibianeError ERRE[UR]


" Object types
syn keyword gibianeType MOT ENTIER FLOTTANT LOGIQUE
syn keyword gibianeType MAILLAGE LISTENTI POINT LISTREEL
syn keyword gibianeType CHPOINT RIGIDITE TEXTE STRUCTUR
syn keyword gibianeType ATTACHE SOLUTION BASEMODA CHAMELEM
syn keyword gibianeType AFFECTE VECTDOUB LISTMOTS DEFORME
syn keyword gibianeType LISTCHPO CHARGEME EVOLUTIO MODELE
syn keyword gibianeType VECTEUR TABLE PROCEDUR ELEMSTRU
syn keyword gibianeType BLOQSTRU MCHAML MMODEL ANNULE


hi link gibianeComment		Comment
hi link gibianeString		String
hi link gibianeTodo		Todo
hi link gibianeImplicit		Special
hi link gibianeReadWrite	gibianeImplicit
hi link gibianeReadWriteFunc	gibianeImplicit
hi link gibianeProcPerso        Macro
hi link gibianeNumber		Number
hi link gibianeFloat		Float
hi link gibianeType		Structure
hi link gibianeElement		Type
hi link gibianeOperator		Function
hi link gibianeProcedure        Function
hi link gibianeFunction		Function
hi link gibianeError		Error
hi link gibianeLogical	        Boolean
hi link gibianeLoop		Repeat
hi link gibianeConditional	Conditional

let b:current_syntax = "gibiane"
